2020-05-31
    - [Version 0.1a7]
    - Added Japanese Proper Names Dictionary (JMnedict) support
    - Included built-in KRADFILE/RADKFile support
    - Improved command line tools (json, compact mode, etc.)

2017-08-18
    - Support KanjiDic2 (XML/SQLite formats)
        
2016-11-09
    - Release first version to Github
